<?php

namespace OCA\GrueneGroupfolderManagement\Command;

use OC\Core\Command\Base;
use OCA\GrueneGroupfolderManagement\Db\GroupMapper;
use OCA\GrueneGroupfolderManagement\DTO\UpdateGroupDto;
use OCA\GrueneGroupfolderManagement\Manager\DivisionManager;
use OCA\GrueneGroupfolderManagement\Manager\GroupManager;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

class FixPermissionMasks extends Base {
	public function __construct(
		protected GroupMapper $groupMapper,
		protected GroupManager $groupManager,
		protected DivisionManager $divisionManager,
	) {
		parent::__construct();
	}

	protected function configure() {
		$this->setName('gruenegroupfoldermanagement:fix-permission-masks')
			->setDescription('fix groups where the permissions masks are not 31');
		parent::configure();
	}

	protected function execute(InputInterface $input, OutputInterface $output) {
		$affectedGroups = $this->groupMapper->findAllWithWrongPermissionsMask();

		foreach($affectedGroups as $affectedGroup) {
			$output->writeln(json_encode($affectedGroup, JSON_PRETTY_PRINT));

			try {
				$this->groupManager->update($affectedGroup, new UpdateGroupDto(
					divisionAclMask: 31,
					memberAclMask: 31,
					adminAclMask: 31,
				));
			} catch (\Throwable $e) {
				$output->writeln("WARNING: could not update group " . $affectedGroup->getName() . "(id: " . $affectedGroup->getId() . ") of division " . $affectedGroup->getDivisionKey() . ", continuing"); 
			}
		}
		
		return 0;
	}
}