<?php

namespace OCA\GrueneGroupfolderManagement\Command;

use OC\Core\Command\Base;
use OCA\GrueneGroupfolderManagement\Constants\Constants;
use OCA\GrueneGroupfolderManagement\Db\GroupMapper;
use OCA\GrueneGroupfolderManagement\Manager\DirectoryManager;
use OCA\GrueneGroupfolderManagement\Manager\GroupFolderManager;
use OCA\GrueneGroupfolderManagement\Model\Division;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use OCP\Files\IRootFolder;
use \OCP\Files\Folder;

class ListFilePermissions extends Base {
	public function __construct(
		protected IRootFolder $rootFolder,
	) {
		parent::__construct();
	}

	protected function configure() {
		$this->setName('gruenegroupfoldermanagement:list-all-files-of-user')
			->addArgument('user', InputArgument::REQUIRED)
			->setDescription('list all files and their permissions of users');
		parent::configure();
	}

	protected function execute(InputInterface $input, OutputInterface $output) {
		$user = $input->getArgument('user');

		$userFolder = $this->rootFolder->getUserFolder($user);

		$this->recursivelyPrintFolder("/", $userFolder, $output);

		return 0;
	}

	protected function recursivelyPrintFolder(string $prefix, Folder $folder, OutputInterface $output) {
		foreach($folder->getDirectoryListing() as $subnode) {
			$output->writeln($prefix . $subnode->getName() . ": " . $subnode->getPermissions());

			if($subnode instanceof Folder) {
				$this->recursivelyPrintFolder($prefix . $subnode->getName() . "/", $subnode, $output);
			}
		}
	}
}